@@ -17,11 +17,6 @@
  * @short_description: code generation for PowerPC
  */
 
-
-void orc_compiler_powerpc_init (OrcCompiler *compiler);
-void orc_compiler_powerpc_assemble (OrcCompiler *compiler);
-void orc_compiler_powerpc_register_rules (OrcTarget *target);
-
 const char *
 powerpc_get_regname(int i)
 {
@@ -423,7 +418,7 @@ orc_powerpc_flush_cache (OrcCode *code)
   int size = code->code_size;
 
   ptr = code->code;
-#ifdef __powerpc64__
+#if defined(__powerpc64__) && (!defined(_CALL_ELF) || _CALL_ELF == 1)
   *(unsigned char **) ptr = (unsigned char *) code->exec + 24;
 #endif
   for (i=0;i<size;i+=cache_line_size) {
