@@ -18,17 +18,14 @@
 
 #define ORC_SSE_ALIGNED_DEST_CUTOFF 64
 
-void orc_sse_emit_loop (OrcCompiler *compiler, int offset, int update);
+static void orc_sse_emit_loop (OrcCompiler *compiler, int offset, int update);
 
-void orc_compiler_sse_init (OrcCompiler *compiler);
-unsigned int orc_compiler_sse_get_default_flags (void);
-void orc_compiler_sse_assemble (OrcCompiler *compiler);
 void orc_compiler_sse_register_rules (OrcTarget *target);
-void orc_sse_emit_invariants (OrcCompiler *compiler);
+static void orc_compiler_sse_init (OrcCompiler *compiler);
+static unsigned int orc_compiler_sse_get_default_flags (void);
+static void orc_compiler_sse_assemble (OrcCompiler *compiler);
+static void orc_sse_emit_invariants (OrcCompiler *compiler);
 
-
-void orc_compiler_rewrite_vars (OrcCompiler *compiler);
-void orc_compiler_dump (OrcCompiler *compiler);
 void sse_load_constant (OrcCompiler *compiler, int reg, int size, int value);
 void sse_load_constant_long (OrcCompiler *compiler, int reg,
     OrcConstant *constant);
@@ -83,12 +80,12 @@ orc_sse_init (void)
   orc_compiler_sse_register_rules (&sse_target);
 }
 
-unsigned int
+static unsigned int
 orc_compiler_sse_get_default_flags (void)
 {
   unsigned int flags = 0;
 
-#ifdef __amd64__
+#if defined(HAVE_AMD64)
   flags |= ORC_TARGET_SSE_64BIT;
 #endif
   if (_orc_compiler_flag_debug) {
@@ -135,7 +132,7 @@ sse_get_flag_name (int shift)
   return NULL;
 }
 
-void
+static void
 orc_compiler_sse_init (OrcCompiler *compiler)
 {
   int i;
@@ -764,8 +761,51 @@ orc_program_has_float (OrcCompiler *compiler)
 #define LABEL_STEP_DOWN(x) (8+(x))
 #define LABEL_STEP_UP(x) (13+(x))
 
+static void
+orc_compiler_sse_save_registers (OrcCompiler *compiler)
+{
+  int i;
+  int saved = 0;
+  for (i = 0; i < 16; ++i) {
+    if (compiler->save_regs[X86_XMM0 + i] == 1) {
+      ++saved;
+    }
+  }
+  if (saved > 0) {
+    orc_x86_emit_mov_imm_reg (compiler, 4, 16 * saved, compiler->gp_tmpreg);
+    orc_x86_emit_sub_reg_reg (compiler, compiler->is_64bit ? 8 : 4,
+        compiler->gp_tmpreg, X86_ESP);
+    saved = 0;
+    for (i = 0; i < 16; ++i) {
+      if (compiler->save_regs[X86_XMM0 + i] == 1) {
+        orc_x86_emit_mov_sse_memoffset (compiler, 16, X86_XMM0 + i,
+            saved * 16, X86_ESP, FALSE, FALSE);
+        ++saved;
+      }
+    }
+  }
+}
 
-void
+static void
+orc_compiler_sse_restore_registers (OrcCompiler *compiler)
+{
+  int i;
+  int saved = 0;
+  for (i = 0; i < 16; ++i) {
+    if (compiler->save_regs[X86_XMM0 + i] == 1) {
+      orc_x86_emit_mov_memoffset_sse (compiler, 16, saved * 16, X86_ESP,
+          X86_XMM0 + i, FALSE);
+      ++saved;
+    }
+  }
+  if (saved > 0) {
+    orc_x86_emit_mov_imm_reg (compiler, 4, 16 * saved, compiler->gp_tmpreg);
+    orc_x86_emit_add_reg_reg (compiler, compiler->is_64bit ? 8 : 4,
+        compiler->gp_tmpreg, X86_ESP);
+  }
+}
+
+static void
 orc_compiler_sse_assemble (OrcCompiler *compiler)
 {
 #ifndef MMX
@@ -804,6 +844,8 @@ orc_compiler_sse_assemble (OrcCompiler *compiler)
 
   orc_x86_emit_prologue (compiler);
 
+  orc_compiler_sse_save_registers (compiler);
+
 #ifndef MMX
   if (orc_program_has_float (compiler)) {
     set_mxcsr = TRUE;
@@ -990,6 +1032,9 @@ orc_compiler_sse_assemble (OrcCompiler *compiler)
 #else
   orc_x86_emit_emms (compiler);
 #endif
+
+  orc_compiler_sse_restore_registers (compiler);
+
   orc_x86_emit_epilogue (compiler);
 
   orc_x86_calculate_offsets (compiler);
@@ -998,7 +1043,7 @@ orc_compiler_sse_assemble (OrcCompiler *compiler)
   orc_x86_do_fixups (compiler);
 }
 
-void
+static void
 orc_sse_emit_loop (OrcCompiler *compiler, int offset, int update)
 {
   int j;
@@ -1082,7 +1127,7 @@ orc_sse_emit_loop (OrcCompiler *compiler, int offset, int update)
   }
 }
 
-void
+static void
 orc_sse_emit_invariants (OrcCompiler *compiler)
 {
   int j;
